import 'package:geiger_localstorage/geiger_localstorage.dart';
import 'package:geiger_localstorage/src/serialization/byte_sink.dart';
import 'package:geiger_localstorage/src/serialization/byte_stream.dart';
import 'package:geiger_localstorage/src/visibility.dart';
import 'package:geiger_localstorage/src/db/data/node_implementation.dart';
import 'package:test/test.dart';

class NodeTest {}

void main() {
  test('node defaults', () {
    var node = NodeImpl('name', 'path');
    expect(node.owner, '', reason: 'test predefined owner');
    expect(node.visibility, Visibility.red,
        reason: 'test predefined owner');
  });

  test('node equality equals()', () {
    var node = NodeImpl('name', 'path');
    var node2 = node.deepClone();
    expect(node.equals(node2), true, reason: 'equality not given');
  });

  test('ordinals mismatch', () {
    var node = NodeImpl('name', 'path');
    var node2 = node.deepClone();
    node2.owner='newOwner';
    expect(node.equals(node2), false);
  });

  test('equality for child nodes', () {
    var node = NodeImpl('name', 'path');
    var node2 = node.deepClone();
    node2.addChild(NodeImpl('name2', 'path:name'));
    expect(node.equals(node2), false);
  });

  test('node serialization' , () async {
    var node = NodeImpl('name', 'path');
    ByteSink sink = ByteSink();
    node.toByteArrayStream(sink);
    sink.close();
    ByteStream stream = ByteStream(null,await sink.bytes);
    Node n2=await NodeImpl.fromByteArrayStream(stream);
    expect(n2,node);
  });
}
